OC.L10N.register(
    "settings",
    {
    "Migration in progress. Please wait until the migration is finished" : "მიმდინარეობს მიგრაცია. გთხოვთ დაელოდოთ მიგრაციის დასრულებას",
    "Migration started …" : "მიგრაცია დაიწყო …",
    "Saved" : "დამახსოვრდა",
    "Not saved" : "არაა შენახული",
    "Sending…" : "იგზავნება…",
    "Email sent" : "ელ-წერილი გაიგზავნა",
    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "წარმოიქმნა შეცდომა. გთხოვთ ატვირთოთ ASCII-თ კოდირებული PEM სერტიფიკატი.",
    "Valid until {date}" : "ვარგისია {date}-მდე",
    "Delete" : "წაშლა",
    "Local" : "ლოკალური",
    "Private" : "პირადი",
    "Only visible to local users" : "გამოჩნდება მხოლოდ ლოკალურ მომხმარებლებთან",
    "Only visible to you" : "გამოჩნდება მხოლოდ თქვენთან",
    "Contacts" : "კონტაქტები",
    "Visible to local users and to trusted servers" : "გამოჩნდება ლოკალურ მომხმარებლებთან და სანდო სერვერებთან",
    "Public" : "ღია",
    "Will be synced to a global and public address book" : "სინქრონიზაცია მოხდება გლობალურ და ღია მისამართების წიგნში",
    "Verify" : "დამოწმება",
    "Verifying …" : "მოწმდება …",
    "Unable to change password" : "პაროლის ცვილება შეუძლებელია",
    "Very weak password" : "ძალიან სუსტი პაროლი",
    "Weak password" : "სუსტი პაროლი",
    "So-so password" : "ნორმალური პაროლი",
    "Good password" : "კარგი პაროლი",
    "Strong password" : "ძლიერი პაროლ",
    "Select a profile picture" : "აირჩიეთ პროფილის სურათი",
    "Groups" : "ჯგუფები",
    "{actor} changed your password" : "{actor} მომხმარებელმა შეცვალა თქვენი პაროლი",
    "You changed your password" : "თქვენ შეცვალეთ თქვენი პაროლი",
    "Your password was reset by an administrator" : "თქვენი პაროლი ადმინისტრატორმა აღადგინა",
    "{actor} changed your email address" : "{actor} მომხმარებელმა შეცვალა თქვენი ელ-ფოსტის მისამართი",
    "You changed your email address" : "თქვენ შეცვალეთ თქვენი ელ-ფოსტის მისამართი",
    "Your email address was changed by an administrator" : "თქვენი ელ-ფოსტის მისამართი ადმინისტრატორის მიერ შეიცვალა",
    "Security" : "უსაფრთხოება",
    "You successfully logged in using two-factor authentication (%1$s)" : "თქვენ ორ-ფაქტორიანი აუტენტიფიკაციით წარმატებით გაიარეთ ავტორიზაცია (%1$s)",
    "A login attempt using two-factor authentication failed (%1$s)" : "ავტორიზაცია ორ-ფაქტორიანი აუტენტიფიკაციით ვერ მოხერხდა (%1$s)",
    "Your <strong>password</strong> or <strong>email</strong> was modified" : "<strong>თქვენი პაროლი</strong> ან <strong>ელ-ფოსტის მისამართი</strong> შეიცვალა",
    "Couldn't remove app." : "აპლიკაციის წაშლა ვერ მოხერხდა.",
    "Couldn't update app." : "აპლიკაციის განახლება ვერ მოხერხდა.",
    "Wrong password" : "არასწორი პაროლი",
    "No user supplied" : "მომხმარებელი არ იქნა მოწოდებული",
    "Authentication error" : "აუტენტიფიკაციის შეცდომა",
    "Please provide an admin recovery password; otherwise, all user data will be lost." : "გთხოვთ მოგვაწოდოთ ადმინისტრატორის აღდგენის პაროლი; სხვა შემთხვევაში ყველა მონაცემი დაიკარგება.",
    "Wrong admin recovery password. Please check the password and try again." : "ადმინისტრატორის აღდგენის არასწორი პაროლი. გთხოვთ გადაამოწმოთ პაროლი და სცადოთ ახლიდან.",
    "Backend doesn't support password change, but the user's encryption key was updated." : "ბექენდს არ აქვს პაროლის ცვლილების მხარდაჭერა, თუმცა მომხმარებლის შიფრაციის გასაღები განახლდა.",
    "installing and updating apps via the app store or Federated Cloud Sharing" : "აპლიკაციების app store-იდან დაყენება და განახლება ან ფედერალური ქლაუდ გაზიარება",
    "Federated Cloud Sharing" : "ფედერალური ქლაუდ გაზიარება",
    "Invalid SMTP password." : "არასწორი SMTP პაროლი.",
    "Email setting test" : "ელ-ფოსტის დაყენების შემოწმება",
    "Well done, %s!" : "ყველაფერი კარგადაა, %s!",
    "If you received this email, the email configuration seems to be correct." : "იმ შემთხვევაში თუ მიიღეთ ეს ელ-წერილი, ელ-ფოსტის კონფიგურაცია კარგად უნდა იყოს.",
    "Email could not be sent. Check your mail server log" : "ელ-წერილი ვერ იგზავნება. გთხოვთ შეამოწმოთ მეილ-სერვერის ლოგი",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "ელ-წერილის გაგზავნისას წარმოიშვა შეცდომა. გთხოვთ გადახედოთ თქვენს პარამეტრებს. (შეცდომა: %s)",
    "You need to set your user email before being able to send test emails." : "შემოწმების წერილების გაგზავნამდე, უნდა დააყენოთ თქვენი მომხმარებლის ელ-ფოსტა.",
    "Invalid mail address" : "არასწორი საფოსტო მისამართი",
    "Settings saved" : "პარამეტრები შენახულია",
    "Unable to change full name" : "სრული სახელის ცვლილება ვერ ხერხდება",
    "Unable to change email address" : "ელ-ფოსტის მისამართი ვერ იცვლება",
    "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "თქვენი Twitter-ის ანგარიშის დასამოწმებლად, Twitter-ზე დაპოსტეთ შემდეგი (მიაქციათ ყურადღება რომ პოსტავთ ხაზის წყვეტის გარეშე): ",
    "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "თქვენი საიტის დასამოწმებლად, შემდეგი მოცულობა მოათავსეთ web-root-ში '.well-known/CloudIdVerificationCode.txt' ადგილას (დარწმუნდით რომ მთელი ტექსტი ერთ ხაზზეა): ",
    "%1$s changed your password on %2$s." : "%1$s მომხმარებელმა თქვენი პაროლი შეცვალა %2$s-ზე.",
    "Your password on %s was changed." : "თქვენი პაროლი %s-ზე შეიცვალა.",
    "Your password on %s was reset by an administrator." : "თქვენი პაროლი %s-ზე ადმინისტრატორმა აღადგინა.",
    "Password for %1$s changed on %2$s" : "პაროლი %1$s-სთვის შეიცვალა %2$s-ზე",
    "Password changed for %s" : "პაროლი %s-სთვის შეიცვალა",
    "If you did not request this, please contact an administrator." : "თუ ეს არ მოგითხოვიათ, მიმართეთ ადმინისტრატორს",
    "Your email address on %s was changed." : "თქვენი ელ-ფოსტის მისამართი %s-ზე შეიცვალა.",
    "Your email address on %s was changed by an administrator." : "თქვენი ელ-ფოსტის მისამართი %s-ზე ადმინისტრატორმა შეცვალა.",
    "Email address for %1$s changed on %2$s" : "ელ-ფოსტის მისამართი %1$s-სთვის შეიცვალა %2$s-ზე",
    "Email address changed for %s" : "ელ-ფოსტის მისამართი %s-სთვის შეიცვალა",
    "The new email address is %s" : "ახალი ელ-ფოსტის მისამართია %s",
    "Your %s account was created" : "თქვენი %s ანგარიში შექმნილია",
    "Welcome aboard" : "კეთილი იყოს თქვენი ბორტზე მობრძანება",
    "Welcome aboard %s" : "%s, კეთილი იყოს თქვენი ბორტზე მობრძანება",
    "Welcome to your %s account, you can add, protect, and share your data." : "კეთილი იყოს თქვენი %s ანგარიშში მობრძანება, შეგიძლიათ დაამატოთ, დაიცვათ და გააზიაროთ თქვენი მონაცემები.",
    "Your username is: %s" : "თქვენი მომხმარებლის სახელია: %s",
    "Set your password" : "დააყენეთ თქვენი პაროლი",
    "Go to %s" : "გადადით %s-ზე",
    "Install Client" : "დააყენეთ კლიენტი",
    "Unlimited" : "ულიმიტო",
    "Limit to groups" : "ლიმიტი ჯგუფებზე",
    "Official apps are developed by and within the community. They offer central functionality and are ready for production use." : "ოფიციალური აპლიკაციები განვითარებულია და მოქცეულია ჩვენს საზოგადოებაში. ისინი გთავაზობენ ცენტრალურ ფუნქციონირებას და საწარმოო გამოყენებისათვის მზადყოფნაში არიან.",
    "Official" : "ოფიციალური",
    "Remove" : "წაშლა",
    "Disable" : "გამორთვა",
    "All" : "ყველა",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "ეს აპლიკაცია არ საზღვრავს Nextcloud-ის მინიმალურ ვერსიას. სამომავლოდ ეს ჩაითვლება შეცდომად.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "ეს აპლიკაცია არ საზღვრავს Nextcloud-ის მაქსიმალურ ვერსიას. სამომავლოდ ეს ჩაითვლება შეცდომად.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "ეს აპლიკაცია ვერ დაყენდა რადგან შემდეგი დამოკიდებულებები არაა დაკმაყოფილებული:",
    "View in store" : "იხილეთ store-ში",
    "Visit website" : "საიტზე სტუმრობა",
    "Report a bug" : "განაცხადეთ შეცდომის შესახებ",
    "User documentation" : "მომხმარებლის დოკუმენტაცია",
    "Admin documentation" : "ადმინისტრატორის დოკუმენტაცია",
    "Developer documentation" : "დეველოპერის დოკუმენტაცია",
    "No apps found for your version" : "აპლიკაციები თქვენი ვერსიისთვის ვერ იქნა ნაპოვნი",
    "Enable all" : "ყველას ამოქმედება",
    "Enable" : "ჩართვა",
    "The app will be downloaded from the app store" : "აპლიკაცია გადმოწერილ იქნება app store-იდან",
    "Allow filesystem access" : "ფაილ-სისტემაზე წვდომის მინიჭება",
    "Revoke" : "წვდომის გაუქმება",
    "Internet Explorer" : "Internet Explorer-ი",
    "Edge" : "Edge-ი",
    "Firefox" : "Firefox-ი",
    "Google Chrome" : "Google Chrome-ი",
    "Safari" : "Safari",
    "Google Chrome for Android" : "Google Chrome Android-ისთვის",
    "Sync client - {os}" : "სინქ. კლიენტი - {os}",
    "This session" : "ეს სესია",
    "Device" : "მოწყობილობა",
    "Last activity" : "ბოლო აქტივობა",
    "Web, desktop and mobile clients currently logged in to your account." : "ვებ, დესკტოპ და მობილური კლიენტები ამჟამად ავტორიზირებული თქვენს ანგარიშზე.",
    "Error while creating device token" : "მოწყობილობის ტოკენის ჩატვირთვისას წარმოიქმნა შეცდომა",
    "Error while deleting the token" : "ტოკენის წაშლისას წარმოიქმნა შეცდომა",
    "App name" : "აპლიკაციის სახელი",
    "Create new app password" : "ახალი აპლიკაციის პაროლის შექმნა",
    "Use the credentials below to configure your app or device." : "ქვემოთ მოცემული უფლებამოსილებანის გამოყენება აპლიკაციისა თუ მოწყობილობისთვის.",
    "For security reasons this password will only be shown once." : "უსაფრთხოების მიზნით ეს პაროლი გამოჩნდება მხოლოდ ერთხელ.",
    "Username" : "მომხმარებლის სახელი",
    "Password" : "პაროლი",
    "Done" : "დასრულებულია",
    "Copied!" : "კოპირებულია",
    "Copy" : "კოპირება",
    "New password" : "ახალი პაროლი",
    "{size} used" : "მოხმარებულია {size}",
    "Email" : "ელ-ფოსტა",
    "Group admin for" : "ადმინისტრატორის შეჯგუფება",
    "Quota" : "ქვოტა",
    "Language" : "ენა",
    "Storage location" : "საცავის ადგილმდებარეობა",
    "User backend" : "მომხმარებელის ბექენდი",
    "Last login" : "ბოლო ავტორიზაცია",
    "Default quota" : "საწყისი კვოტა",
    "Your apps" : "თქვენი აპლიკაციები",
    "Disabled apps" : "არამოქმედი აპლიკაციები",
    "Updates" : "განახლებები",
    "App bundles" : "აპლიკაციის შეკვრები",
    "Show last login" : "ბოლო ავტორიზაციის ჩვენება",
    "Show user backend" : "მომხმარებლის ბექენდის ჩვენება",
    "Admins" : "ადმინისტრატორები",
    "Everyone" : "ყველა",
    "Add group" : "ჯგუფის დამატება",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "აპლიკაცია ამოქმედდა, თუმცა საჭიროებს განახლებას. 5 წამში გადამისამართდებით განახლების გვერდზე.",
    "App update" : "აპლიკაციის განახლება",
    "Error: This app can not be enabled because it makes the server unstable" : "შეცდომა: ეს აპლიკაცია ვერ მოქმედდება რადგანაც სერვერს ხდის არასტაბილურს",
    "SSL Root Certificates" : "SSL Root სერტიფიკატები",
    "Common Name" : "საზოგადო სახელი",
    "Valid until" : "ვარგისია",
    "Issued By" : "განაცხადა",
    "Valid until %s" : "ვარგისია %s-მდე",
    "Import root certificate" : "Root სერტიფიკატის იმპორტი",
    "Administrator documentation" : "ადმინისტრატორის დოკუმენტაცია",
    "Forum" : "ფორუმი",
    "None" : "არც ერთი",
    "Login" : "ლოგინი",
    "Plain" : "ჩვეულებრივი",
    "NT LAN Manager" : "NT LAN მენეჯერი",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "Email server" : "საფოსტო სერვერი",
    "Open documentation" : "ღია დოკუმენტაცია",
    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "ამ სერვერის მოწყობა ელ-წერილების გასაგზვნად მნიშვნელოვანია, მაგ. პაროლის აღსადგენად და შეტყობინებების მისაღებად.",
    "Send mode" : "გაგზავნის რეჟიმი",
    "Encryption" : "შიფრაცია",
    "From address" : "მისამართიდან",
    "mail" : "წერილი",
    "Authentication method" : "აუტენტიფიკაციის მეთოდი",
    "Authentication required" : "აუტენტიფიკაცია საჭიროებს",
    "Server address" : "სერვერის მისამართი",
    "Port" : "პორტი",
    "Credentials" : "უფლებამოსილებანი",
    "SMTP Username" : "SMTP მოხმარებლის სახელი",
    "SMTP Password" : "SMTP მომხმარებლის პაროლი",
    "Test email settings" : "ელ-ფოსტის პარამეტრების შემომება",
    "Send email" : "ელ-წერილის გაგზავნა",
    "Security & setup warnings" : "უსაფრთხოების და მოწყობის გაფრთხილებები",
    "All checks passed." : "ყველა შემოწმებამ ჩაიარა დადებითად.",
    "Version" : "ვერსია",
    "Server-side encryption" : "სერვერული-მხარის შიფრაცია",
    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "სერვერული-მხარის შიფრაცია იძლევა სერვერზე ატვირთული ფაილების შიფრაციის საშუალებას. ეს ფუნქცია ლიმიტს აწესებს მოქმედებაზე, ასე რომ გააქტიურედ მხოლოდ აუცილებლობისას.",
    "Enable server-side encryption" : "სერვერული-მხარის შიფრაციის ამოქმედება",
    "Please read carefully before activating server-side encryption: " : "სანამ გააქტიურებთ სერვერული-მხარის შიფრაციას გთხოვთ ყურადღებით გაეცნოთ:",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "შიფრაციის ჩართვის შემდეგ, სერვერზე ატვირთული ყველა ფაილი დაიშიფრება. იმ შემთხვევაში თუ აქტიური შიფრაციის მოდულს აქვს შიფრაციის დეაქტივაციის უნარი და ყველა წინაპირობა დაცულია (მაგ.: აღდგენის გასაღების დაყენება), სხვა დროს შეძლებთ მისი მოქმედების შეჩერებას.",
    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "მხოლოდ შიფრაცია არ იძლევა სისტემის უსაფრთხოების გარანტიას. მეტი ინფორმაციისთვის იმაზე თუ როგორ მუშაობს შიფრაციის აპლიკაცია იხილეთ დოკუმენტაცია და გაეცანით მოხმარების შემთხვევებს.",
    "Be aware that encryption always increases the file size." : "იცოდეთ, შიფრაცია ყოველთვის ზრდის ფაილის ზომას.",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "ყოველთვის კარგია თქვენი მონაცემების დაზღვევა, შიფრაციის შემთხვევაში თვენს მონაცემებთან ერთად აუცილებლად დააზღვიეთ შიფრაციის გასაღებებიც.",
    "This is the final warning: Do you really want to enable encryption?" : "ეს ბოლო გაფრთხილებაა: ნამდვილად გსურთ შიფრაციის ამოქმედება?",
    "Enable encryption" : "შიფრაციის ამოქმედება",
    "No encryption module loaded, please enable an encryption module in the app menu." : "შიფრაციის მოდული არაა ჩატვირთული, გთხოვთ აამოქმედოთ ის აპლიკაციის მენიუდან. ",
    "Select default encryption module:" : "აირჩიეთ შიფრაციის საწყისი მოდული:",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "საჭიროა შიფრაციის გასაღებების მიგრაცია (ownCloud <= 8.0) ახალებზე. გთხოვთ აამოქმედოთ \"საწყისი მიგრაციის მოდული\" და გაუშვათ 'occ encryption:migrate'",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "საჭიროა შიფრაციის ძველი გასაღებების მიგრაცია (ownCloud <= 8.0) ახალებზე.",
    "Start migration" : "მიგრაციის დაწყება",
    "Background jobs" : "ფონური საქმეები",
    "Last job ran %s." : "ბოლო საქმის გაშვება - %s.",
    "Last job execution ran %s. Something seems wrong." : "ბოლო საქმე გაიშვა %s. რაღაც არასწორია.",
    "Background job didn’t run yet!" : "ფონური საქმე ჯერ არ გაშვებულა!",
    "For optimal performance it's important to configure background jobs correctly. For bigger instances 'Cron' is the recommended setting. Please see the documentation for more information." : "ოპტიმალური მოღვაწეობისთვის მნიშვნელოვანია ფონური საქმეების სწორი კონფიგურაცია. დიდი ინსტანციებისთვის 'კრონი' რეკომენდირებული არჩევანია. გთხოვთ მეტი ინფორმაციისთვის იხილოთ დოკუმენტაცია.",
    "Execute one task with each page loaded" : "გაუშვი თითო მოქმედება ყველა ჩატვირთულ გვერდზე",
    "The cron.php needs to be executed by the system user \"%s\"." : "cron.php უნდა გაუშვას სისტემურმა მოხმარებელმა \"%s\".",
    "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "ამის გასაშვებად საჭიროა გქონდეთ PHP POSIX გაფართოება. მეტი დეტალებისთვის იხილეთ {linkstart}PHP დოკუმენტაცია{linkend}. ",
    "Sharing" : "გაზიარება",
    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "როგორც ადმინისტრატორს შეგიძლიათ გაზიარების ქცევის კორექტირება. დამატებითი ინფორმაციისთვის იხილეთ დოკუმენტაცია.",
    "Allow apps to use the Share API" : "დაუშვი აპლიკაციების უფლება  Share API –ზე",
    "Allow users to share via link" : "მიეცით მოხმარებლებს ბმულით გაზიარების უფლება",
    "Allow public uploads" : "საქვეყნო ატვირთების დაშვება",
    "Always ask for a password" : "ყოველთვის მოხდეს პაროლის მოთხოვნა",
    "Enforce password protection" : "პროლით დაცვის იძულება",
    "Set default expiration date" : "დააყენეთ საწყისი ვადის ამოწურვის თარიღი",
    "Expire after " : "ვადის ამოწურვა",
    "days" : "დღე",
    "Enforce expiration date" : "ვადის ამოწურვის თარიღის იძულება",
    "Allow resharing" : "ხელახალი გაზიარების დაშვება",
    "Allow sharing with groups" : "ჯგუფებთან გაზიარების მხარდაჭერა",
    "Restrict users to only share with users in their groups" : "შეზღუდეთ მომხმარებლები გააზიარონ მომხმარებლებთან, რომლებიც მიეკუთვნებიან მათ ჯგუფებს",
    "Exclude groups from sharing" : "აკრძალეთ ჯგუფების გაზიარება",
    "These groups will still be able to receive shares, but not to initiate them." : "ეს ჯგუფები ისევ მიიღებენ გაზიარებებს, მაგრამ ვერ წამოიწყებენ მათ.",
    "Allow username autocompletion in share dialog. If this is disabled the full username or email address needs to be entered." : "მიეცით მომხმარებლებს ავტოდასრულების უფლება გაზიარების დიალოგებში. იმ შემთხვევაში თუ ეს ფუნქცია არაა მოქმედი, საჭირო იქნება სრული მომხმარებლის სახელის ან ელ-ფოსტის მისამართის შეყვანა.",
    "Show disclaimer text on the public link upload page. (Only shown when the file list is hidden.)" : "პასუხისმგებლობის შეზღუდვის ტექსტის ჩვენება ღია ბმულის ატვირთვის გვერდზე. (ჩანს მხოლოდ მაშინ, როდესაც ფაილების სია დამალულია.)",
    "This text will be shown on the public link upload page when the file list is hidden." : "ეს ტექსტი გამოჩნდება ღია ბმულის ატვირთვის გვერდზე, როდესაც ფაილების სია დამალულია.",
    "Default share permissions" : "საწყისი გაზიარების პარამეტრები",
    "Personal" : "პირადი",
    "Administration" : "ადმინისტრაცია",
    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "განავითარა {communityopen}Nextcloud საზოგადოებამ{linkclose}, {githubopen}კოდი{linkclose} is ლიცენზირებულია {licenseopen}AGPL ლიცენზიით{linkclose}.",
    "Like our Facebook page" : "მოიწონეთ ჩვენი Facebook გვერდი",
    "Follow us on Twitter" : "გამოგვყევით Twitter-ზე",
    "Check out our blog" : "იხილეთ ჩვენი ბლოგი",
    "Subscribe to our newsletter" : "გამოიწერეთ ჩვენი სიახლეები",
    "Profile picture" : "პროფილის სურათი",
    "Upload new" : "ახალი ატვირთვა",
    "Select from Files" : "აირჩიეთ ფაილებიდან",
    "Remove image" : "სურათის წაშლა",
    "png or jpg, max. 20 MB" : "png ან jpg, მაქს. 20 მბ",
    "Picture provided by original account" : "სურათი ორიგინალი ანგარიშიდან",
    "Cancel" : "უარყოფა",
    "Choose as profile picture" : "აირჩიეთ პროფილის სურათად",
    "Full name" : "სრული სახელი",
    "No display name set" : "დისპლეი სახელი არაა დაყენებული",
    "Your email address" : "თქვენი ელ-ფოსტის მისამართი",
    "No email address set" : "ელ-ფოსტის მისამართი არაა დაყენებული",
    "For password reset and notifications" : "პაროლის აღდგენისთვის და შეტყობინებებისთვის",
    "Phone number" : "ტელეფონის ნომერი",
    "Your phone number" : "თქვენი ტელეფონის ნომერი",
    "Address" : "მისამართი",
    "Your postal address" : "თქვენი საფოსტო მისამართი",
    "Website" : "ვებ-საიტი",
    "It can take up to 24 hours before the account is displayed as verified." : "თქვენი ანგარიშის ვერიფიცირებულად გამოჩენამ შეიძლება გასტანოს 24 საათი.",
    "Link https://…" : "ბმული https://…",
    "Twitter" : "Twitter-ი",
    "Twitter handle @…" : "Twitter @…",
    "Help translate" : "თარგმნის დახმარება",
    "Current password" : "მიმდინარე პაროლი",
    "Change password" : "პაროლის შეცვლა",
    "Store credentials" : "უფლებამოსილებანის შენახვა",
    "cron.php is registered at a webcron service to call cron.php every 15 minutes over HTTP." : "cron.php რეგისტრირებულია ვებკრონის სერვისით რომ 15 წუთში ერთხელ HTTP-თი გაიშვას.",
    "Use system cron service to call the cron.php file every 15 minutes." : "გამოიყენეთ სისტემის კრონი cron.php ფაილის გასაშვებად ყოველ 15 წუთში."
},
"nplurals=2; plural=(n!=1);");
